/*
 * @(#)IChannelLoggerFactory.java
 *
 * Copyright (C) 2002-2003 Matt Albrecht
 * groboclown@users.sourceforge.net
 * http://groboutils.sourceforge.net
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the 
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in 
 *  all copies or substantial portions of the Software. 
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 *  DEALINGS IN THE SOFTWARE.
 */

package net.sourceforge.groboutils.codecoverage.v2;

import java.util.Properties;


/**
 * Creates a channel logger.  Used by the singleton <tt>CoverageLogger</tt>
 * to dynamically create the logger being used for the runtime execution.
 *
 * @author    Matt Albrecht <a href="mailto:groboclown@users.sourceforge.net">groboclown@users.sourceforge.net</a>
 * @version   $Date: 2003/02/10 22:51:25 $
 * @since     December 15, 2002
 */
public interface IChannelLoggerFactory
{
    /**
     * Creates a specific logger type.  Initializes the logger based on the
     * given collection of properties.
     *
     * @param propertyPrefix the prefix that all logger properties will begin
     *    with.  Expect all logger-specific properties to be appended directly
     *    to this string.
     * @param props the property collection to pull the logger properties from.
     * @param channelIndex channel number to log to.
     * @return the initialized logger.
     */
    public IChannelLogger createChannelLogger(
            String propertyPrefix, Properties props, short channelIndex );
}

