/*
 * @(#)IIssueTypeInfoUTestI.java
 *
 * Copyright (C) 2002-2003 Matt Albrecht
 * groboclown@users.sourceforge.net
 * http://groboutils.sourceforge.net
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the 
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in 
 *  all copies or substantial portions of the Software. 
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 *  DEALINGS IN THE SOFTWARE.
 */

package net.sourceforge.groboutils.pmti.v1;

import net.sourceforge.groboutils.autodoc.v1.AutoDoc;
import org.easymock.EasyMock;
import org.easymock.MockControl;
import net.sourceforge.groboutils.junit.v1.iftc.*;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;


/**
 * Tests the IIssueTypeInfo interface.
 *
 * @author    Matt Albrecht <a href="mailto:groboclown@users.sourceforge.net">groboclown@users.sourceforge.net</a>
 * @since     July 14, 2002
 * @version   $Date: 2003/02/10 22:52:01 $
 */
public class IIssueTypeInfoUTestI extends InterfaceTestCase
{
    //-------------------------------------------------------------------------
    // Standard JUnit Class-specific declarations
    
    private static final Class THIS_CLASS = IIssueTypeInfoUTestI.class;
    private static final AutoDoc DOC = new AutoDoc( THIS_CLASS );
    
    public IIssueTypeInfoUTestI( String name, ImplFactory f )
    {
        super( name, IIssueTypeInfo.class, f );
    }

    
    public IIssueTypeInfo createIIssueTypeInfo()
    {
        return (IIssueTypeInfo)createImplObject();
    }


    //-------------------------------------------------------------------------
    // Tests
    
    public void testGetName1()
    {
        IIssueTypeInfo iti = createIIssueTypeInfo();
        String name = iti.getName();
        assertNotNull(
            "Name must not be null.",
            name );
    }
    
    
    public void testGetPossibleStates1()
    {
        IIssueTypeInfo iti = createIIssueTypeInfo();
        IIssueState[] is = iti.getPossibleStates();
        assertNotNull(
            "Possible state array must not be null.",
            is );
        for (int i = 0; i < is.length; ++i)
        {
            assertNotNull(
                "Possible state index "+i+" is null.",
                is[i] );
        }
    }
    
    
    public void testGetSupportedAttributes1()
    {
        IIssueTypeInfo iti = createIIssueTypeInfo();
        IAttributeInfo[] ai = iti.getSupportedAttributes();
        assertNotNull(
            "Supported attribute array must not be null.",
            ai );
        for (int i = 0; i < ai.length; ++i)
        {
            assertNotNull(
                "Supported attribute index "+i+" is null.",
                ai[i] );
        }
    }
    
    
    public void testGetTestPassedStates1()
    {
        IIssueTypeInfo iti = createIIssueTypeInfo();
        IIssueState[] is = iti.getTestPassedStates();
        assertNotNull(
            "Test passed state array must not be null.",
            is );
        for (int i = 0; i < is.length; ++i)
        {
            assertNotNull(
                "Test passed state index "+i+" is null.",
                is[i] );
        }
    }
    
    
    public void testGetTestFailedStates1()
    {
        IIssueTypeInfo iti = createIIssueTypeInfo();
        IIssueState[] is = iti.getTestFailedStates();
        assertNotNull(
            "Test failed state array must not be null.",
            is );
        for (int i = 0; i < is.length; ++i)
        {
            assertNotNull(
                "Test failed state index "+i+" is null.",
                is[i] );
        }
    }
    
    
    
    //-------------------------------------------------------------------------
    // Standard JUnit declarations
    
    
    public static InterfaceTestSuite suite()
    {
        InterfaceTestSuite suite = new InterfaceTestSuite( THIS_CLASS );
        
        return suite;
    }
    
    public static void main( String[] args )
    {
        String[] name = { THIS_CLASS.getName() };
        
        // junit.textui.TestRunner.main( name );
        // junit.swingui.TestRunner.main( name );
        
        junit.textui.TestRunner.main( name );
    }
    
    
    /**
     * 
     * @exception Exception thrown under any exceptional condition.
     */
    protected void setUp() throws Exception
    {
        super.setUp();
        
        // set ourself up
    }
    
    
    /**
     * 
     * @exception Exception thrown under any exceptional condition.
     */
    protected void tearDown() throws Exception
    {
        // tear ourself down
        
        
        super.tearDown();
    }
}

