/*
 *  @(#)AutoDocLogSet.java
 *
 * Copyright (C) 2002-2003 Matt Albrecht
 * groboclown@users.sourceforge.net
 * http://groboutils.sourceforge.net
 *
 *  Part of the GroboUtils package at:
 *  http://groboutils.sourceforge.net
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the 
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in 
 *  all copies or substantial portions of the Software. 
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 *  DEALINGS IN THE SOFTWARE.
 */
package net.sourceforge.groboutils.autodoc.v1.defimpl;


import net.sourceforge.groboutils.autodoc.v1.AutoDocLog;

import java.util.Vector;
import java.util.Enumeration;
 

/**
 * An interface for logging.  This allows for an abstraction between the
 * owning class and any underlying logging mechanism desired.
 * <P>
 * The actual meaning of the logging levels is implementation independent.
 *
 * @author     Matt Albrecht <a href="mailto:groboclown@users.sourceforge.net">groboclown@users.sourceforge.net</a>
 * @version    $Date: 2003/02/10 22:52:11 $
 * @since      June 28, 2002
 */
public class AutoDocLogSet implements AutoDocLog, IAutoDocSet
{
    private Vector set = new Vector();
    
    public void addLog( AutoDocLog log )
    {
        this.set.addElement( log );
    }
    
    
    public Enumeration getSetContents()
    {
        return this.set.elements();
    }
    
    
    public void debug( Object message )
    {
        Enumeration enum = getSetContents();
        while (enum.hasMoreElements())
        {
            ((AutoDocLog)enum.nextElement()).debug( message );
        }
    }

    public void debug( Object message[] )
    {
        Enumeration enum = getSetContents();
        while (enum.hasMoreElements())
        {
            ((AutoDocLog)enum.nextElement()).debug( message );
        }
    }
    
    public void debug( Object message, Throwable error )
    {
        Enumeration enum = getSetContents();
        while (enum.hasMoreElements())
        {
            ((AutoDocLog)enum.nextElement()).debug( message, error );
        }
    }

    public void debug( Object message[], Throwable error )
    {
        Enumeration enum = getSetContents();
        while (enum.hasMoreElements())
        {
            ((AutoDocLog)enum.nextElement()).debug( message, error );
        }
    }
    
    public void info( Object message )
    {
        Enumeration enum = getSetContents();
        while (enum.hasMoreElements())
        {
            ((AutoDocLog)enum.nextElement()).info( message );
        }
    }

    public void info( Object message[] )
    {
        Enumeration enum = getSetContents();
        while (enum.hasMoreElements())
        {
            ((AutoDocLog)enum.nextElement()).info( message );
        }
    }
    
    public void info( Object message, Throwable error )
    {
        Enumeration enum = getSetContents();
        while (enum.hasMoreElements())
        {
            ((AutoDocLog)enum.nextElement()).info( message, error );
        }
    }

    public void info( Object message[], Throwable error )
    {
        Enumeration enum = getSetContents();
        while (enum.hasMoreElements())
        {
            ((AutoDocLog)enum.nextElement()).info( message, error );
        }
    }
    
    public void warn( Object message )
    {
        Enumeration enum = getSetContents();
        while (enum.hasMoreElements())
        {
            ((AutoDocLog)enum.nextElement()).warn( message );
        }
    }

    public void warn( Object message[] )
    {
        Enumeration enum = getSetContents();
        while (enum.hasMoreElements())
        {
            ((AutoDocLog)enum.nextElement()).warn( message );
        }
    }
    
    public void warn( Object message, Throwable error )
    {
        Enumeration enum = getSetContents();
        while (enum.hasMoreElements())
        {
            ((AutoDocLog)enum.nextElement()).warn( message, error );
        }
    }
    
    public void warn( Object message[], Throwable error )
    {
        Enumeration enum = getSetContents();
        while (enum.hasMoreElements())
        {
            ((AutoDocLog)enum.nextElement()).warn( message, error );
        }
    }
}

