/*
 * @(#)Log4jLogUTest.java
 *
 * Copyright (C) 2002-2003 Matt Albrecht
 * groboclown@users.sourceforge.net
 * http://groboutils.sourceforge.net
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 *  DEALINGS IN THE SOFTWARE.
 */

package net.sourceforge.groboutils.autodoc.v1.log4j;

import net.sourceforge.groboutils.autodoc.v1.*;

import net.sourceforge.groboutils.junit.v1.iftc.*;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;


/**
 * Tests the Log4jLog class.
 *
 * @author    Matt Albrecht <a href="mailto:groboclown@users.sourceforge.net">groboclown@users.sourceforge.net</a>
 * @version   $Date: 2003/05/27 13:32:51 $
 * @since     March 28, 2002
 */
public class Log4jLogUTest extends TestCase
{
    //-------------------------------------------------------------------------
    // Standard JUnit Class-specific declarations
    
    private static final Class THIS_CLASS = Log4jLogUTest.class;
    
    public Log4jLogUTest( String name )
    {
        super( name );
    }

    
    //-------------------------------------------------------------------------
    // setup
    
    /**
     * 
     * @exception Exception thrown under any exceptional condition.
     */
    protected void setUp() throws Exception
    {
        super.setUp();
        
        // set ourself up
    }


    //-------------------------------------------------------------------------
    // Tests
    
    
    public void testConstructor1()
    {
        try
        {
            new Log4jLog( (Class)null );
            fail("did not throw IllegalArgumentException.");
        }
        catch (IllegalArgumentException e)
        {
            // test exception?
        }
    }
    
    
    public void testConstructor2()
    {
        new Log4jLog( this.getClass() );
    }
    
    
    public void testConstructor3()
    {
        try
        {
            new Log4jLog( (org.apache.log4j.Logger)null );
            fail("did not throw IllegalArgumentException.");
        }
        catch (IllegalArgumentException e)
        {
            // test exception?
        }
    }
    
    
    public void testConstructor4()
    {
        new Log4jLog( org.apache.log4j.Logger.getLogger( this.getClass() ) );
    }
    
    
    public void testConcatMessage1()
    {
        Log4jLog log = new Log4jLog( this.getClass() );
        Object sb = log.concatMessage( null );
        assertNotNull(
            "concatMessage must not return null.",
            sb );
        assertEquals(
            "did not concat objects correctly.",
            "null",
            sb.toString() );
    }
    
    
    public void testConcatMessage2()
    {
        Log4jLog log = new Log4jLog( this.getClass() );
        Object sb = log.concatMessage( new Object[0] );
        assertNotNull(
            "concatMessage must not return null.",
            sb );
        assertEquals(
            "did not concat objects correctly.",
            "",
            sb.toString() );
    }
    
    
    public void testConcatMessage3()
    {
        Log4jLog log = new Log4jLog( this.getClass() );
        Object sb = log.concatMessage( new Object[1] );
        assertNotNull(
            "concatMessage must not return null.",
            sb );
        assertEquals(
            "did not concat objects correctly.",
            "null",
            sb.toString() );
    }
    
    
    public void testConcatMessage4()
    {
        Log4jLog log = new Log4jLog( this.getClass() );
        Object sb = log.concatMessage( new Object[]
            { "a", "b" } );
        assertNotNull(
            "concatMessage must not return null.",
            sb );
        assertEquals(
            "did not concat objects correctly.",
            "ab",
            sb.toString() );
    }
    
    
    public void testConcatMessage5()
    {
        Log4jLog log = new Log4jLog( this.getClass() );
        StringBuffer sb = (StringBuffer)log.concatMessage( new Object[]
            { "a", null, "b" } );
        assertNotNull(
            "concatMessage must not return null.",
            sb );
        assertEquals(
            "did not concat objects correctly.",
            "anullb",
            sb.toString() );
    }
    
    
    //-------------------------------------------------------------------------
    // Helpers
    
    
    //-------------------------------------------------------------------------
    // Standard JUnit declarations
    
    
    public static Test suite()
    {
        InterfaceTestSuite suite = AutoDocLogUTestI.suite();
        suite.addTestSuite( THIS_CLASS );
        suite.addFactory( new CxFactory( "A" ) {
            public Object createImplObject() {
                return new Log4jLog( Test.class );
            }
        } );
        
        return suite;
    }
    
    public static void main( String[] args )
    {
        String[] name = { THIS_CLASS.getName() };
        
        // junit.textui.TestRunner.main( name );
        // junit.swingui.TestRunner.main( name );
        
        junit.textui.TestRunner.main( name );
    }
    
    
    /**
     * 
     * @exception Exception thrown under any exceptional condition.
     */
    protected void tearDown() throws Exception
    {
        // tear ourself down
        
        super.tearDown();
    }
}

