/*
 * @(#)MonitorUTestI.java
 *
 * Copyright (C) 2002-2003 Matt Albrecht
 * groboclown@users.sourceforge.net
 * http://groboutils.sourceforge.net
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the 
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in 
 *  all copies or substantial portions of the Software. 
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 *  DEALINGS IN THE SOFTWARE.
 */

package net.sourceforge.groboutils.autodoc.v1.testserver;

import net.sourceforge.groboutils.autodoc.v1.*;

//import net.sourceforge.groboutils.testing.junitlog.v1.*;
import org.easymock.EasyMock;
import org.easymock.MockControl;
import net.sourceforge.groboutils.junit.v1.iftc.*;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;


/**
 * Tests the Monitor interface.
 *
 * @author    Matt Albrecht <a href="mailto:groboclown@users.sourceforge.net">groboclown@users.sourceforge.net</a>
 * @since     March 27, 2002
 * @version   $Date: 2003/02/10 22:52:17 $
 */
public class MonitorUTestI extends InterfaceTestCase
{
    //-------------------------------------------------------------------------
    // Standard JUnit Class-specific declarations
    
    private static final Class THIS_CLASS = MonitorUTestI.class;
//    private static final IJUnitDocumentor LOG = (new JUnitLog(THIS_CLASS)).getDocumentor();
    
    public MonitorUTestI( String name, ImplFactory f )
    {
        super( name, Monitor.class, f );
    }

    
    public Monitor createMonitor()
    {
        return (Monitor)createImplObject();
    }


    //-------------------------------------------------------------------------
    // Tests
    
    public void testAddTestData1()
    {
        Monitor m = createMonitor();
        try
        {
            m.addTestData( null );
            fail("Did not throw IllegalArgumentException");
        }
        catch (IllegalArgumentException e)
        {
            // check exception?
        }
    }
    
    
    public void testAddTestData2()
    {
        Monitor m = createMonitor();
        TestInfo ti = new DefaultTestInfo( "a", "b" );
        m.addTestData( ti );
    }
    
    
    public void testAddTestData3()
    {
        Monitor m = createMonitor();
        TestInfo ti = new DefaultTestInfo( "a", "b" );
        m.addTestData( ti );
        try
        {
            m.addTestData( ti );
            fail("Did not throw an IllegalStateException");
        }
        catch (IllegalStateException e)
        {
            // check exception?
        }
    }
    
    
    public void testGetTestData1()
    {
        Monitor m = createMonitor();
        try
        {
            m.getTestData( null );
            fail("Did not throw IllegalArgumentException");
        }
        catch (IllegalArgumentException e)
        {
            // check exception?
        }
    }
    
    
    public void testGetTestData2()
    {
        Monitor m = createMonitor();
        TestInfo ti = new DefaultTestInfo( "a", "b" );
        try
        {
            m.getTestData( ti );
            fail("Did not throw IllegalStateException");
        }
        catch (IllegalStateException e)
        {
            // check exception?
        }
    }
    
    
    public void testGetTestData3()
    {
        Monitor m = createMonitor();
        TestInfo ti = new DefaultTestInfo( "a", "b" );
        m.addTestData( ti );
        TestData td = m.getTestData( ti );
        assertNotNull(
            "returned null on valid test info.",
            td );
        assertTrue(
            "A new get did not return the exact same object.",
            td == m.getTestData( ti ) );
    }
    
    
    public void testSendTestData1()
    {
        Monitor m = createMonitor();
        try
        {
            m.sendTestData( null );
            fail("Did not throw IllegalArgumentException");
        }
        catch (IllegalArgumentException e)
        {
            // check exception?
        }
    }
    
    
    public void testSendTestData2()
    {
        Monitor m = createMonitor();
        TestInfo ti = new DefaultTestInfo( "a", "b" );
        try
        {
            m.sendTestData( ti );
            fail("Did not throw IllegalStateException");
        }
        catch (IllegalStateException e)
        {
            // check exception?
        }
    }
    
    
    public void testSendTestData3()
    {
        Monitor m = createMonitor();
        TestInfo ti = new DefaultTestInfo( "a", "b" );
        m.addTestData( ti );
        m.sendTestData( ti );
        try
        {
            m.getTestData( ti );
            fail("Did not throw IllegalStateException");
        }
        catch (IllegalStateException ise)
        {
            // test exception?
        }
    }
    
    
    //-------------------------------------------------------------------------
    // Standard JUnit declarations
    
    
    public static InterfaceTestSuite suite()
    {
        InterfaceTestSuite suite = new InterfaceTestSuite( THIS_CLASS );
        
        return suite;
    }
    
    public static void main( String[] args )
    {
        String[] name = { THIS_CLASS.getName() };
        
        // junit.textui.TestRunner.main( name );
        // junit.swingui.TestRunner.main( name );
        
        junit.textui.TestRunner.main( name );
    }
    
    
    /**
     * 
     * @exception Exception thrown under any exceptional condition.
     */
    protected void setUp() throws Exception
    {
        super.setUp();
        
        // set ourself up
    }
    
    
    /**
     * 
     * @exception Exception thrown under any exceptional condition.
     */
    protected void tearDown() throws Exception
    {
        // tear ourself down
        
        
        super.tearDown();
    }
}

