/*
 * @(#)AsmblStateSetUTest.java
 *
 * Copyright (C) 2002-2003 Matt Albrecht
 * groboclown@users.sourceforge.net
 * http://groboutils.sourceforge.net
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the 
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in 
 *  all copies or substantial portions of the Software. 
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 *  DEALINGS IN THE SOFTWARE.
 */

package net.sourceforge.groboutils.mbtf.v1.assembler;

import org.easymock.EasyMock;
import org.easymock.MockControl;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;


/**
 * Tests the AsmblStateSet class.
 *
 * @author    Matt Albrecht <a href="mailto:groboclown@users.sourceforge.net">groboclown@users.sourceforge.net</a>
 * @version   $Date: 2003/02/10 22:52:27 $
 * @since     June 17, 2002
 */
public class AsmblStateSetUTest extends TestCase
{
    //-------------------------------------------------------------------------
    // Standard JUnit Class-specific declarations
    
    private static final Class THIS_CLASS = AsmblStateUTest.class;
    
    public AsmblStateSetUTest( String name )
    {
        super( name );
    }

    
    //-------------------------------------------------------------------------
    // setup

    /**
     * 
     * @exception Exception thrown under any exceptional condition.
     */
    protected void setUp() throws Exception
    {
        super.setUp();
        
        // set ourself up
    }


    //-------------------------------------------------------------------------
    // Tests
    
    
    public void testConstructor1()
    {
        new AsmblStateSet();
    }
    
    
    public void testAddState1()
    {
        AsmblStateSet ats = new AsmblStateSet();
        ats.addState( null );
        AsmblState[] v = ats.getStates();
        assertNotNull(
            "states returned null.",
            v );
        assertEquals(
            "states size not right.",
            0,
            v.length );
    }
    
    
    public void testAddState2()
    {
        AsmblState at = new AsmblState();
        AsmblStateSet ats = new AsmblStateSet();
        ats.addState( at );
        AsmblState[] v = ats.getStates();
        assertNotNull(
            "states returned null.",
            v );
        assertEquals(
            "states size not right.",
            1,
            v.length );
        assertEquals(
            "states inserted not returned.",
            at,
            v[0] );
    }
    
    
    public void testAddStates1()
    {
        AsmblStateSet ats = new AsmblStateSet();
        ats.addStates( null );
        AsmblState[] v = ats.getStates();
        assertNotNull(
            "states returned null.",
            v );
        assertEquals(
            "states size not right.",
            0,
            v.length );
    }
    
    
    public void testAddStates2()
    {
        AsmblState[] at = new AsmblState[0];
        AsmblStateSet ats = new AsmblStateSet();
        ats.addStates( at );
        AsmblState[] v = ats.getStates();
        assertNotNull(
            "states returned null.",
            v );
        assertEquals(
            "states size not right.",
            0,
            v.length );
    }
    
    
    public void testAddStates3()
    {
        AsmblState[] at = new AsmblState[1];
        AsmblStateSet ats = new AsmblStateSet();
        ats.addStates( at );
        AsmblState[] v = ats.getStates();
        assertNotNull(
            "states returned null.",
            v );
        assertEquals(
            "states size not right.",
            0,
            v.length );
    }
    
    
    public void testAddStates4()
    {
        AsmblState at = new AsmblState();
        AsmblState atlist[] = new AsmblState[1];
        atlist[0] = at;
        AsmblStateSet ats = new AsmblStateSet();
        ats.addStates( atlist );
        AsmblState[] v = ats.getStates();
        assertNotNull(
            "states returned null.",
            v );
        assertEquals(
            "states size not right.",
            1,
            v.length );
        assertEquals(
            "states inserted not returned.",
            at,
            v[0] );
    }
    
    
    public void testAddStates5()
    {
        AsmblState at = new AsmblState();
        AsmblState atlist[] = new AsmblState[2];
        atlist[0] = at;
        AsmblStateSet ats = new AsmblStateSet();
        ats.addStates( atlist );
        AsmblState[] v = ats.getStates();
        assertNotNull(
            "states returned null.",
            v );
        assertEquals(
            "states size not right.",
            1,
            v.length );
        assertEquals(
            "states inserted not returned.",
            at,
            v[0] );
    }
    
    
    //-------------------------------------------------------------------------
    // Helpers
    
    
    //-------------------------------------------------------------------------
    // Standard JUnit declarations
    
    
    public static Test suite()
    {
        TestSuite suite = new TestSuite( THIS_CLASS );
        
        // Test the implementation's interface conformity.
        /*
        suite.addTest( IxUTestI.suite(
            new ImplementationCreator[] {
                new ImplementationCreator() {
                    public Object createImplementedObject() {
                        // XXXXXXXXXXXXXXXXXXXXXXXX
                    }
                },
            } ) );
        */
        return suite;
    }
    
    public static void main( String[] args )
    {
        String[] name = { THIS_CLASS.getName() };
        
        // junit.textui.TestRunner.main( name );
        // junit.swingui.TestRunner.main( name );
        
        junit.textui.TestRunner.main( name );
    }
    
    
    /**
     * 
     * @exception Exception thrown under any exceptional condition.
     */
    protected void tearDown() throws Exception
    {
        // tear ourself down
        
        super.tearDown();
    }
}

