/*
 * @(#)BreadthPathGeneratorUTest.java
 *
 * Copyright (C) 2002-2003 Matt Albrecht
 * groboclown@users.sourceforge.net
 * http://groboutils.sourceforge.net
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the 
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in 
 *  all copies or substantial portions of the Software. 
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 *  DEALINGS IN THE SOFTWARE.
 */

package net.sourceforge.groboutils.mbtf.v1.engine;

import org.easymock.EasyMock;
import org.easymock.MockControl;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import java.util.Hashtable;

import net.sourceforge.groboutils.mbtf.v1.assembler.*;
import net.sourceforge.groboutils.mbtf.v1.*;

/**
 * Tests the BreadthPathGenerator class.
 *
 * @author    Matt Albrecht <a href="mailto:groboclown@users.sourceforge.net">groboclown@users.sourceforge.net</a>
 * @version   $Date: 2003/02/10 22:52:28 $
 * @since     June 17, 2002
 */
public class BreadthPathGeneratorUTest extends TestCase
{
    //-------------------------------------------------------------------------
    // Standard JUnit Class-specific declarations
    
    private static final Class THIS_CLASS = BreadthPathGeneratorUTest.class;
    
    public BreadthPathGeneratorUTest( String name )
    {
        super( name );
    }

    
    //-------------------------------------------------------------------------
    // setup

    /**
     * 
     * @exception Exception thrown under any exceptional condition.
     */
    protected void setUp() throws Exception
    {
        super.setUp();
        
        // set ourself up
    }


    //-------------------------------------------------------------------------
    // Tests
    
    
    private static class MyAction implements IAction
    {
        public void performAction( ISystem s, IErrors e ) {}
    }
    
    
    
    public void testInnerStateConstructor1()
    {
        try
        {
            new BreadthPathGenerator.InnerState( null, null );
            fail("Did not throw IllegalArgumentException");
        }
        catch (IllegalArgumentException e)
        {
            // check exception
        }
    }
    
    public void testInnerStateConstructor2()
    {
        try
        {
            new BreadthPathGenerator.InnerState( null, new Hashtable() );
            fail("Did not throw IllegalArgumentException");
        }
        catch (IllegalArgumentException e)
        {
            // check exception
        }
    }
    
    public void testInnerStateConstructor3()
    {
        AsmblState state = new AsmblState();
        state.setName( "state" );
        AsmblTransitionSet ats = new AsmblTransitionSet();
        try
        {
            new BreadthPathGenerator.InnerState( state.createState( ats ), null );
            fail("Did not throw IllegalArgumentException");
        }
        catch (IllegalArgumentException e)
        {
            // check exception
        }
    }

    
    public void testConstructor1()
    {
        try
        {
            new BreadthPathGenerator( null, null );
            fail("did not throw IllegalArgumentException");
        }
        catch (IllegalArgumentException iae)
        {
            // check exception
        }
    }

    
    public void testStructure1()
    {
        AsmblState state1 = new AsmblState();
        state1.setName( "state1" );
        state1.addTransitionName( "trans1" );
        AsmblStateSet ass = new AsmblStateSet();
        ass.addState( state1 );

        AsmblTransition trans1 = new AsmblTransition();
        trans1.setName( "trans1" );
        trans1.setNextStateName( "state1" );
        trans1.setAction( new MyAction() );
        AsmblTransitionSet ats = new AsmblTransitionSet();
        ats.addTransition( trans1 );
        
        Assembler asm = new Assembler( ats, ass );

        new BreadthPathGenerator( asm.getStates(), null );
    }
    
    
    
    //-------------------------------------------------------------------------
    // Helpers
    
    public void assertEquals( String msg, Object[] left, Object[] right )
    {
        if (left == null)
        {
            assertNull( msg, right );
        }
        else
        {
            assertNotNull( msg, right );
            assertEquals( msg, left.length, right.length );
            for (int i = left.length; ++i >= 0;)
            {
                assertEquals( msg, left[i], right[i] );
            }
        }
    }
    
    //-------------------------------------------------------------------------
    // Standard JUnit declarations
    
    
    public static Test suite()
    {
        TestSuite suite = new TestSuite( THIS_CLASS );
        
        // Test the implementation's interface conformity.
        /*
        suite.addTest( IxUTestI.suite(
            new ImplementationCreator[] {
                new ImplementationCreator() {
                    public Object createImplementedObject() {
                        // XXXXXXXXXXXXXXXXXXXXXXXX
                    }
                },
            } ) );
        */
        return suite;
    }
    
    public static void main( String[] args )
    {
        String[] name = { THIS_CLASS.getName() };
        
        // junit.textui.TestRunner.main( name );
        // junit.swingui.TestRunner.main( name );
        
        junit.textui.TestRunner.main( name );
    }
    
    
    /**
     * 
     * @exception Exception thrown under any exceptional condition.
     */
    protected void tearDown() throws Exception
    {
        // tear ourself down
        
        super.tearDown();
    }
}

