/*
 * @(#)AllowCapturePassThroughAdapter.java
 *
 * Copyright (C) 2002-2003 Matt Albrecht
 * groboclown@users.sourceforge.net
 * http://groboutils.sourceforge.net
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the 
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in 
 *  all copies or substantial portions of the Software. 
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 *  DEALINGS IN THE SOFTWARE.
 */

package net.sourceforge.groboutils.uicapture.v1.event;



/**
 * An adapter for IAllowCapturePassThroughListener.  All instances must
 * also be of type ICaptureListener.  By default, all these events
 * allow passthrough.
 *
 * @author    Matt Albrecht <a href="mailto:groboclown@users.sourceforge.net">groboclown@users.sourceforge.net</a>
 * @version   Jan 4, 2002
 */
public class AllowCapturePassThroughAdapter extends CaptureAdapter
        implements IAllowCapturePassThroughListener
{
    /**
     * @see java.awt.event.MouseWheelListener
     * @return <tt>true</tt> to allow the event to passed to the underlying
     *      UI, or <tt>false</tt> to 'swallow' the event.
     */
    public boolean allowMouseWheelMoved( MouseWheelCaptureEvent ce )
    {
        return true;
    }
    
    
    /**
     * @see java.awt.event.MouseListener
     * @return <tt>true</tt> to allow the event to passed to the underlying
     *      UI, or <tt>false</tt> to 'swallow' the event.
     */
    public boolean allowMousePressed( MousePressedCaptureEvent ce )
    {
        return true;
    }
    
    
    /**
     * @see java.awt.event.MouseListener
     * @return <tt>true</tt> to allow the event to passed to the underlying
     *      UI, or <tt>false</tt> to 'swallow' the event.
     */
    public boolean allowMouseReleased( MouseReleasedCaptureEvent ce )
    {
        return true;
    }
    
    
    /**
     * @see java.awt.event.KeyListener
     * @return <tt>true</tt> to allow the event to passed to the underlying
     *      UI, or <tt>false</tt> to 'swallow' the event.
     */
    public boolean allowKeyPressed( KeyPressedCaptureEvent ce )
    {
        return true;
    }
    
    
    /**
     * @see java.awt.event.KeyListener
     * @return <tt>true</tt> to allow the event to passed to the underlying
     *      UI, or <tt>false</tt> to 'swallow' the event.
     */
    public boolean allowKeyReleased( KeyReleasedCaptureEvent ce )
    {
        return true;
    }
}

