/*
 * @(#)MouseWheelCaptureEvent.java
 *
 * Copyright (C) 2002-2003 Matt Albrecht
 * groboclown@users.sourceforge.net
 * http://groboutils.sourceforge.net
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the 
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in 
 *  all copies or substantial portions of the Software. 
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 *  DEALINGS IN THE SOFTWARE.
 */

package net.sourceforge.groboutils.uicapture.v1.event;

import java.awt.Robot;
import java.awt.event.InputEvent;
import java.awt.event.MouseEvent;
import java.awt.event.MouseWheelEvent;


/**
 * An event object which stores a capture event.
 * <P>
 * Requires JDK 1.4+
 *
 * @author    Matt Albrecht <a href="mailto:groboclown@users.sourceforge.net">groboclown@users.sourceforge.net</a>
 * @version   Jan 4, 2002
 */
public class MouseWheelCaptureEvent extends MouseCaptureEvent
{
    /**
     * @serial
     */
    private int rotation = 0;
    
    public MouseWheelCaptureEvent( MouseWheelEvent event )
    {
        super( CE_MOUSE_WHEEL, (MouseEvent)event );
        
        this.rotation = event.getWheelRotation();
    }
    
    
    public MouseWheelCaptureEvent( int rotation )
    {
        super( CE_MOUSE_WHEEL );
        
        this.rotation = rotation;
    }
    
    
    public int getWheelRotation()
    {
        return this.rotation;
    }
    
    
    /**
     * Reenacts the event that this CaptureEvent represents underneath it
     * all.
     */
    public void performEvent( Robot r )
    {
        super.performEvent( r );
        r.mouseWheel( getWheelRotation() );
    }
}

